<?php

declare(strict_types=1);

namespace Drupal\page_cache_vary;

use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceModifierInterface;
use Drupal\Core\DependencyInjection\ServiceProviderInterface;
use Symfony\Component\DependencyInjection\Compiler\PassConfig;

/**
 * Defines a service provider for the Internal Page Cache Vary module.
 *
 * Remove the PageCache services to avoid any collisions. It's not possible to
 * just disable the page_cache module, otherwise we will not be able to extend
 * it for \Drupal\page_cache_vary\StackMiddleware\PageCacheVary.
 *
 * @see https://www.drupal.org/node/2026959
 */
final class PageCacheVaryServiceProvider implements ServiceProviderInterface {

  /**
   * Register the VaryCacheContextPass compiler pass.
   */
  public function register(ContainerBuilder $container): void {
    $container->addCompilerPass(new VaryCacheContextCleanPass(), PassConfig::TYPE_BEFORE_OPTIMIZATION, 1000);
    $container->addCompilerPass(new VaryCacheContextPass());
  }

}
