<?php

namespace Drupal\page_cache_vary;

use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;

/**
 * Remove http_middleware.page_cache and cache.page services from service definition.
 *

 *
 * @see \Drupal\Core\Cache\Context\CacheContextsPass
 */
class VaryCacheContextCleanPass implements CompilerPassInterface {

  /**
   * Remove services in collision with what is provided in page_cache_vary.
   *
   *  Some modules (ex. subrequests,
   *  https://git.drupalcode.org/project/subrequests/-/commit/bee4766b196235dada31264921c0e8cc4ad71f4f) requires the
   *  http_middleware.page_cache service to be available if the module page_cache is available.
   *  Avoid any issue with it not being available by removing the module from the list of available modules.
   */
  public function process(ContainerBuilder $container) {
    $modules = $container->getParameter('container.modules');
    if (array_key_exists('subrequests', $modules)) {
      unset($modules['page_cache']);
      $container->setParameter('container.modules', $modules);
    }

    $container->removeDefinition('http_middleware.page_cache');
    $container->removeDefinition('cache.page');
  }

}
