<?php

declare(strict_types=1);

namespace Drupal\page_cache_vary_test\Cache\Context;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CalculatedCacheContextInterface;
use Drupal\Core\Cache\Context\RequestStackCacheContextBase;
use Drupal\page_cache_vary\VaryCacheContextInterface;

/**
 * Varies the context depending on the x-country-code header.
 *
 * Cache context ID: 'country'.
 *
 * @DCG
 * Check out the core/lib/Drupal/Core/Cache/Context directory for examples of
 * cache contexts provided by Drupal core.
 */
final class CountryCacheContext extends RequestStackCacheContextBase implements CalculatedCacheContextInterface, VaryCacheContextInterface {

  const COUNTRY_CODE_HEADER = 'x-country-code';

  /**
   * {@inheritdoc}
   */
  public static function getLabel(): string {
    return (string) t('Country');
  }

  /**
   * {@inheritdoc}
   */
  public function getContext($parameter = NULL): string {
    return $this->requestStack->getMainRequest()->headers->get(self::COUNTRY_CODE_HEADER, '');
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata($parameter = NULL): CacheableMetadata {
    return new CacheableMetadata();
  }

  /**
   * {@inheritDoc}
   */
  public function getVaryHeaders(): array {
    return [self::COUNTRY_CODE_HEADER];
  }

}
